==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/pt_PT.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Hiperligação Pública",
    "Photos" : "Fotos",
    "On This Day" : "Neste dia",
    "Your memories under your control" : "As suas memórias estão sob o seu controlo",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Neste dia",
    "Shared with you" : "Partilhado consigo",
    "Tags" : "Etiquetas",
    "Places" : "Locais",
    "Map" : "Mapa",
    "Photos settings" : "Definições do Fotos",
    "This name is already in use." : "Este nome já está em uso.",
    "Invalid filename." : "Nome de ficheiro inválido",
    "Name of the album" : "Name of the album",
    "Location of the album" : "Location of the album",
    "Back" : "Anterior",
    "Add collaborators" : "Add collaborators",
    "Save" : "Guardar",
    "Create album" : "Create album",
    "Shared by" : "Partilhado por",
    "Create new album" : "Create new album",
    "New album" : "New album",
    "Failed to fetch collaborators list." : "Failed to fetch collaborators list.",
    "Failed to update album." : "Failed to update album.",
    "Add people or groups who can edit your album" : "Add people or groups who can edit your album",
    "Search people or groups" : "Search people or groups",
    "No recommendations. Start typing." : "Nenhuma recomendação. Comece a escrever ",
    "Copy the public link" : "Copy the public link",
    "Public link copied!" : "Public link copied!",
    "Copy public link" : "Copiar ligação publica",
    "Delete the public link" : "Delete the public link",
    "Share via public link" : "Share via public link",
    "An error occurred" : "Ocorreu um erro",
    "Favorite" : "Favorito",
    "Open the full size \"{name}\" image" : "Abrir a foto \"{name}\" no tamanho original",
    "Go back" : "Voltar",
    "Enable squared photos view" : "Ativar vista de fotos quadradas",
    "Home" : "Início",
    "View" : "Ver",
    "Unselect all" : "Remover seleção",
    "Edit album details" : "Edit album details",
    "Save collaborators for this album." : "Save collaborators for this album.",
    "Rename person" : "Rename person",
    "Merge with different person" : "Merge with different person",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remove person",
    "Loading folders…" : "A carregar pastas…",
    "No photos in here" : "Aqui não existem fotos ",
    "No tags yet" : "Ainda sem marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Add to album" : "Adicionar a álbum",
    "Unassigned faces" : "Unassigned faces",
    "All your media" : "Toda a sua média",
    "Tagged photos" : "Fotos marcadas",
    "Last week" : "Ultima semana",
    "Details" : "Detalhes",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remove {collaboratorLabel} from the collaborators list",
    "Back to {folder}" : "Ir para {folder}",
    "Share this folder" : "Partilhar esta pasta",
    "Add" : "Adicionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/pt_PT.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Hiperligação Pública",
    "Photos" : "Fotos",
    "On This Day" : "Neste dia",
    "Your memories under your control" : "As suas memórias estão sob o seu controlo",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Neste dia",
    "Shared with you" : "Partilhado consigo",
    "Tags" : "Etiquetas",
    "Places" : "Locais",
    "Map" : "Mapa",
    "Photos settings" : "Definições do Fotos",
    "This name is already in use." : "Este nome já está em uso.",
    "Invalid filename." : "Nome de ficheiro inválido",
    "Name of the album" : "Name of the album",
    "Location of the album" : "Location of the album",
    "Back" : "Anterior",
    "Add collaborators" : "Add collaborators",
    "Save" : "Guardar",
    "Create album" : "Create album",
    "Shared by" : "Partilhado por",
    "Create new album" : "Create new album",
    "New album" : "New album",
    "Failed to fetch collaborators list." : "Failed to fetch collaborators list.",
    "Failed to update album." : "Failed to update album.",
    "Add people or groups who can edit your album" : "Add people or groups who can edit your album",
    "Search people or groups" : "Search people or groups",
    "No recommendations. Start typing." : "Nenhuma recomendação. Comece a escrever ",
    "Copy the public link" : "Copy the public link",
    "Public link copied!" : "Public link copied!",
    "Copy public link" : "Copiar ligação publica",
    "Delete the public link" : "Delete the public link",
    "Create public link share" : "Criar link público para partilha",
    "Share via public link" : "Share via public link",
    "An error occurred" : "Ocorreu um erro",
    "Favorite" : "Favorito",
    "Open the full size \"{name}\" image" : "Abrir a foto \"{name}\" no tamanho original",
    "Go back" : "Voltar",
    "Home" : "Início",
    "General" : "Geral",
    "Unselect all" : "Remover seleção",
    "Edit album details" : "Edit album details",
    "Save collaborators for this album." : "Save collaborators for this album.",
    "Rename person" : "Rename person",
    "Merge with different person" : "Merge with different person",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remove person",
    "Loading folders…" : "A carregar pastas…",
    "No photos in here" : "Aqui não existem fotos ",
    "Back to tags overview" : "Voltar à visão geral das etiquetas",
    "No tags yet" : "Ainda sem marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas as etiquetas",
    "Add to album" : "Adicionar a álbum",
    "Unassigned faces" : "Unassigned faces",
    "All your media" : "Toda a sua média",
    "Tagged photos" : "Fotos marcadas",
    "Last week" : "Ultima semana",
    "Details" : "Detalhes",
    "Cancel" : "Cancel",
    "Confirm" : "Confirmar",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remove {collaboratorLabel} from the collaborators list",
    "Back to {folder}" : "Ir para {folder}",
    "Share this folder" : "Partilhar esta pasta",
    "Enable squared photos view" : "Ativar vista de fotos quadradas",
    "View" : "Ver",
    "Add" : "Adicionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
